/* Test suite for Mechanics.asy.
 *
 * Copyright (C) 2008-2009 W. Trevor King <wking@drexel.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */

import Mechanics;

real u = 1cm;

Mass a = Mass(center=(0,0));
Mass b = Mass(center=(2u,1u));
Mass c = Mass(center=(1u,-2u));
Mass ms[] = {a,b, c};
Distance dab = Distance(a.center, b.center, scale=u, L="$r_{ab}$");
Distance dac = Distance(a.center, c.center, scale=u, L="$r_{ac}$");
Distance ds[] = {dab, dac};
Angle bac1 = Angle(
    b.center, a.center, c.center, radius=.7u, fill=red, L="$\theta_T'$");
Angle bac2 = Angle(b.center, a.center, c.center, radius=-.5u, L="$\theta_T$");
Angle as[] = {bac1, bac2};

Vector vs[];

vs.push(ihat(center=(0,u)));
vs.push(jhat(center=(0,u)));

vs.push(Vector(center=(-1u,-4u), phi=90, "Out"));
vs.push(Vector(center=(-1u,-5.5u), phi=-90, "In"));
vs.push(Vector(center=(0, -4u), mag=1.5u, dir=-90, phi=60, "60dg OOP"));

for (int i=0; i<as.length; i+=1)
  as[i].draw();
for (int i=0; i<ms.length; i+=1)
  ms[i].draw();
for (int i=0; i<ds.length; i+=1)
  ds[i].draw();
for (int i=0; i<vs.length; i+=1)
  vs[i].draw();

Pendulum p = makePendulum(pivot=(3.5u,-3u), mass=b, length=4u, angleDeg=-20,
                          angleL="$\rho$", stringL="r");

real len = abs(p.pivot.x-b.center.x);
Spring s = Spring(pFrom=b.center-(2u,0), pTo=b.center, L="$k_1$");  s.draw();
s = Spring(pFrom=b.center, pTo=(p.pivot.x, b.center.y), L="$k_2$"); s.draw();

p.draw(drawVertical=true);

Surface s = Surface(pFrom=(0,-7u), pTo=(3.5u, -7u), L="Table");
s.draw();


Vector v = Velocity();
pair vfc = (5u,0);  // vector field center
real vfwidth = 2u;
real vfheight = 2u;
real vfdv = u/3;
real vfbuf = 2pt;

draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);

vfc -= (0, vfheight + u);
v.dir = 90;
draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);

vfc -= (0, vfheight + u);
v.dir = -180;
draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);

vfc += (vfwidth + u, 2*(vfheight + u));
v.dir = -90;
draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);

vfc -= (0, vfheight + u);
v.dir = -10;
draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);

vfc -= (0, vfheight + u);
v.phi = 90;
draw(shift(vfc)*xscale(vfwidth-2*vfbuf)*yscale(vfheight-2*vfbuf)
     *shift((-.5,-.5))*unitsquare, grey);
vector_field(vfc, width=vfwidth, height=vfheight, dv=vfdv, buf=vfbuf, v=v,
             outline=green+dashed);
