#!/bin/bash
#
# By default, this website is setup for remote installation via SSH.
# This works well if you've setup SSH keys for passwordless login, but
# is annoying otherwise.
#
# An alternative setup would be to keep the source code on the same
# machine as the webserver, and use local CP calls to push the data
# into the hosted directory.  This script converts the default
# codebase into such a local installation.
#
# Usage: ./local-install.sh

set -e # exit immediately on failed command
set -o pipefail # pipes fail if any stage fails
set -v # verbose, echo commands to stdout

echo -e "\nRemove the INSTALL_HOST/USER lines in ./Makefile.\n"
sed -i 's/^INSTALL_HOST =.*//' ./Makefile
sed -i 's/^INSTALL_USER =.*//' ./Makefile
sed -i 's/^export INSTALL_HOST.*//' ./Makefile
sed -i 's/^export INSTALL_USER.*//' ./Makefile

echo -e "\nReplace the SCP with a local CP in all Makefiles.\n"
sed -i 's/scp -p \(.*\) \$(INSTALL_USER)@\$(INSTALL_HOST):\(.*\)$/cp -up \1 \2/' \
    $(find . -name Makefile)


echo -e "\nNo need to SSH into installation host to make directories.\n"
# merge first two lines of multi-line SSH calls
sed -i '
# look for multi-line SSH calls
/ssh \$(INSTALL_USER)@\$(INSTALL_HOST) \\/ {
# got one, read in the next line
                                          N
# concatenate the two lines
                                          s/\\\n\t *//
}' $(find . -name Makefile)
# fix the single-line calls (now all the calls)
sed -i 's/ssh \$(INSTALL_USER)@\$(INSTALL_HOST) \(.*\)$/\1/' \
    $(find . -name Makefile)


echo -e "\nCorrect a few particular details.\n"
# correct a comment
sed -i 's/INSTALL_USER, INSTALL_HOST, //' latex/notes/topics/linear_algebra/Makefile
# adjust shell ecscaping for newly non-SSHed command
sed -i "/cd \\\$(INSTALL_DIR) '&&' rm/ { s/'&&'/\&\&/g }" html/Makefile
#sed -i "s/'&&'/\&\&/" html/Makefile


echo -e "\nStandardize INSTALL_DIR destination in ./Makefile.\n"
sed -i 's/^INSTALL_DIR = .*/INSTALL_DIR = ~\/public_html\//' Makefile
